LayerContainerXml
=================

.. currentmodule:: wwt_data_formats.layers

.. autoclass:: LayerContainerXml
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LayerContainerXml.cross_validation_lock
      ~LayerContainerXml.id
      ~LayerContainerXml.layers
      ~LayerContainerXml.rmeta

   .. rubric:: Methods Summary

   .. autosummary::

      ~LayerContainerXml.add_traits
      ~LayerContainerXml.apply_to_xml
      ~LayerContainerXml.class_own_trait_events
      ~LayerContainerXml.class_own_traits
      ~LayerContainerXml.class_trait_names
      ~LayerContainerXml.class_traits
      ~LayerContainerXml.from_file
      ~LayerContainerXml.from_text
      ~LayerContainerXml.from_url
      ~LayerContainerXml.from_xml
      ~LayerContainerXml.has_trait
      ~LayerContainerXml.hold_trait_notifications
      ~LayerContainerXml.notify_change
      ~LayerContainerXml.observe
      ~LayerContainerXml.on_trait_change
      ~LayerContainerXml.set_trait
      ~LayerContainerXml.setup_instance
      ~LayerContainerXml.to_xml
      ~LayerContainerXml.to_xml_string
      ~LayerContainerXml.trait_defaults
      ~LayerContainerXml.trait_events
      ~LayerContainerXml.trait_has_value
      ~LayerContainerXml.trait_metadata
      ~LayerContainerXml.trait_names
      ~LayerContainerXml.trait_values
      ~LayerContainerXml.traits
      ~LayerContainerXml.unobserve
      ~LayerContainerXml.unobserve_all
      ~LayerContainerXml.write_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: cross_validation_lock
   .. autoattribute:: id
   .. autoattribute:: layers
   .. autoattribute:: rmeta

   .. rubric:: Methods Documentation

   .. automethod:: add_traits
   .. automethod:: apply_to_xml
   .. automethod:: class_own_trait_events
   .. automethod:: class_own_traits
   .. automethod:: class_trait_names
   .. automethod:: class_traits
   .. automethod:: from_file
   .. automethod:: from_text
   .. automethod:: from_url
   .. automethod:: from_xml
   .. automethod:: has_trait
   .. automethod:: hold_trait_notifications
   .. automethod:: notify_change
   .. automethod:: observe
   .. automethod:: on_trait_change
   .. automethod:: set_trait
   .. automethod:: setup_instance
   .. automethod:: to_xml
   .. automethod:: to_xml_string
   .. automethod:: trait_defaults
   .. automethod:: trait_events
   .. automethod:: trait_has_value
   .. automethod:: trait_metadata
   .. automethod:: trait_names
   .. automethod:: trait_values
   .. automethod:: traits
   .. automethod:: unobserve
   .. automethod:: unobserve_all
   .. automethod:: write_xml
